# Input clock to FPGA
create_clock -name CLK24M -period 41.666 [get_ports {CLK24M}]

create_generated_clock \
    -name CLK_CORE \
    -source [get_pins {m_pll|altpll_component|auto_generated|pll1|inclk[0]}] \
    -duty_cycle 50.000 \
    -multiply_by 49 \
    -divide_by 12 \
    -master_clock {CLK24M} \
    [get_pins {m_pll|altpll_component|auto_generated|pll1|clk[0]}] 
    
    
create_generated_clock \
    -name CLK_CORE_1 \
    -source [get_pins {m_pll|altpll_component|auto_generated|pll1|inclk[0]}] \
    -duty_cycle 50.000 \
    -multiply_by 49 \
    -divide_by 12 \
    -phase 157.50 \
    -master_clock {CLK24M} \
    [get_pins {m_pll|altpll_component|auto_generated|pll1|clk[1]}]

create_generated_clock \
    -name CLK_FLASH \
    -source [get_pins {m_pll|altpll_component|auto_generated|pll1|clk[1]}] \
    [get_ports FLASH_SCLK]

derive_clock_uncertainty

# Flash PCB delays, approximate for now
set flash_BD_clk 0.105
set flash_BD_data 0.105

# ****** QSPI FLASH INPUT CONSTRAINTS (QSPI -> FPGA) *********
#tCO_min based on hold time
set flash_tCO_min 2.0
#tCO_max based on running at 3V or greater, 3.3V in this case
set flash_tCO_max 6.0

set_input_delay\
    -clock CLK_FLASH\
    -clock_fall\
    -max [expr $flash_tCO_max + $flash_BD_clk + $flash_BD_data]\
    [get_ports FLASH_IO*]

set_input_delay\
    -clock CLK_FLASH\
    -clock_fall\
    -min [expr + $flash_tCO_min + $flash_BD_clk + $flash_BD_data]\
    [get_ports FLASH_IO*]

set_multicycle_path \
   -setup \
   -end \
   -from [get_clocks CLK_FLASH] \
   -to [get_clocks CLK_CORE] 2

# ****** QSPI FLASH OUTPUT CONSTRAINTS (FPGA -> QSPI) *********
# Flash datasheet specs for setup and hold times
set flash_tSU 2.0
set flash_tH 3.0

set max_flash_output_delay [expr $flash_BD_data + $flash_tSU - $flash_BD_clk]
set min_flash_output_delay [expr $flash_BD_data - $flash_tH - $flash_BD_clk]

set_output_delay -clock CLK_FLASH -max $max_flash_output_delay [get_ports FLASH_IO*]
set_output_delay -clock CLK_FLASH -min $min_flash_output_delay [get_ports FLASH_IO*]
set_output_delay -clock CLK_FLASH -max $max_flash_output_delay [get_ports FLASH_CS]
set_output_delay -clock CLK_FLASH -min $min_flash_output_delay [get_ports FLASH_CS]

set_false_path -to [get_ports FLASH_SCLK]
