module fpga_silo(
    input               CLK24M,     //Master clock input
    
    // Pins connected to flash memory chip
    inout   [3:0]       FLASH_IO,
    output              FLASH_SCLK,
    output              FLASH_CS,
    
    // Signals from flash driver state machine; these are just here so that
    // they are not optimized out and so that they can be used for black
    // box simulation.
    output              FLASH_VALID,
    output  [7:0]       FLASH_BYTE
);
    
    wire pll_is_locked;
    wire clk98meg;      //Master system clock. Generated by PLL.
    wire clk98meg_inv;  //Flash clk
    
    main_pll m_pll(
        .inclk0         (CLK24M),
        .c0             (clk98meg),
        .c1             (clk98meg_inv),
        .locked         (pll_is_locked)
    );
    
    //FLASH_SCLK is inverted
//    ddio_out	ddio_out_inst (
//      .datain_h ( 1'd0 ),
//      .datain_l ( 1'b1 ),
//      .outclock ( clk98meg ),
//      .dataout ( FLASH_SCLK )
//	);
    
   assign FLASH_SCLK = clk98meg_inv;
    
    // The flah driver is designed to be multiport. Even though only one port is used
    // here, the declaration is kept the same as in the full design so that I do not
    // have to rewrite the whole thing.
    flash_port      flash_ports [0:3] ();
    
    // This is a little state machine to send transfer requests to the flash driver.
    // It is just to make sure the flash driver is not optimized out of the build.
    logic [7:0] trigger_count = '0;
    logic trigger = '0;
    always @(posedge clk98meg) begin
        trigger_count <= trigger_count + 1'd1;
        trigger <= (trigger_count == '1);
    end
    assign flash_ports[0].request = trigger;
    assign flash_ports[0].addr_start = '0;
    assign flash_ports[0].length_bytes = 10'd8;
    
    assign FLASH_VALID = flash_ports[0].byte_valid;
    assign FLASH_BYTE = flash_ports[0].data_byte;
    
    flash_driver m_flash_driver(
        .clk                    (clk98meg),
        .ports                  (flash_ports),
        .IO                     (FLASH_IO),
        .CS                     (FLASH_CS)
    );
endmodule
